==> qtjambi-webenginecore-6.5.8-sources.jar: io/qt/webengine/core/QWebEngineQuotaRequest.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineQuotaRequest</code></p>
 */
public class QWebEngineQuotaRequest extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineQuotaRequest.class);
    
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>QWebEngineQuotaRequest()</code></p>
     * 
     * @deprecated Requesting host quota is no longer supported.
     */
    @Deprecated
    public QWebEngineQuotaRequest(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    @Deprecated
    private native static void initialize_native(QWebEngineQuotaRequest instance);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>QWebEngineQuotaRequest(QWebEngineQuotaRequest)</code></p>
     */
    public QWebEngineQuotaRequest(io.qt.webengine.core.@NonNull QWebEngineQuotaRequest other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineQuotaRequest instance, io.qt.webengine.core.QWebEngineQuotaRequest other);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>accept()</code></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>operator==(QWebEngineQuotaRequest)const</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.webengine.core.@NonNull QWebEngineQuotaRequest arg__1){
        return equals_native_cref_QWebEngineQuotaRequest_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QWebEngineQuotaRequest_constfct(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>origin()const</code></p>
     */
    @QtPropertyReader(name="origin")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>reject()</code></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>requestedSize()const</code></p>
     */
    @QtPropertyReader(name="requestedSize")
    @QtPropertyConstant
    @QtUninvokable
    public final long requestedSize(){
        return requestedSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long requestedSize_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineQuotaRequest(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr/>operator==(QWebEngineQuotaRequest)const</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other==null || other instanceof io.qt.webengine.core.QWebEngineQuotaRequest) {
            return equals((io.qt.webengine.core.QWebEngineQuotaRequest) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineQuotaRequest)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QWebEngineQuotaRequest::<wbr/>QWebEngineQuotaRequest(QWebEngineQuotaRequest)</code></p>
     */
    @QtUninvokable
    @Override
    public QWebEngineQuotaRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineQuotaRequest clone_native(long __this_nativeId);
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #origin()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getOrigin() {
        return origin();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #requestedSize()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final long getRequestedSize() {
        return requestedSize();
    }
}

==> qtjambi-webenginecore-6.6.0-sources.jar: io/qt/webengine/core/QWebEngineQuotaRequest.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineQuotaRequest</code></p>
 */
public class QWebEngineQuotaRequest extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineQuotaRequest.class);
    
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>QWebEngineQuotaRequest()</code></p>
     * 
     * @deprecated Requesting host quota is no longer supported.
     */
    @Deprecated
    public QWebEngineQuotaRequest(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    @Deprecated
    private native static void initialize_native(QWebEngineQuotaRequest instance);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>accept()</code></p>
     */
    public final void accept(){
        accept_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void accept_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>operator==(QWebEngineQuotaRequest)const</code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.core.@NonNull QWebEngineQuotaRequest arg__1){
        return operator_equal_native_cref_QWebEngineQuotaRequest_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineQuotaRequest_constfct(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>origin()const</code></p>
     */
    @QtPropertyReader(name="origin")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>reject()</code></p>
     */
    public final void reject(){
        reject_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void reject_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>requestedSize()const</code></p>
     */
    @QtPropertyReader(name="requestedSize")
    @QtPropertyConstant
    @QtUninvokable
    public final long requestedSize(){
        return requestedSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long requestedSize_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineQuotaRequest(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>QWebEngineQuotaRequest::<wbr>operator==(QWebEngineQuotaRequest)const</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineQuotaRequest) {
            return operator_equal((io.qt.webengine.core.QWebEngineQuotaRequest) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineQuotaRequest)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineQuotaRequest clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineQuotaRequest clone_native(long __this_nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #origin()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getOrigin() {
        return origin();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #requestedSize()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final long getRequestedSize() {
        return requestedSize();
    }
}
